%define major     2
%define libname   %mklibname xmlb %major
%define devname   %mklibname xmlb -d

%define gir_major 2.0
%define girname   %mklibname xmlb-gir %{gir_major}

%global glib2_version 2.45.8

Summary:        Library for querying compressed XML metadata
Name:           libxmlb
Group:          System/Libraries
Version:        0.3.22
Release:        %mkrel 1
License:        LGPL-2.1-or-later
URL:            https://github.com/hughsie/libxmlb
Source0:        https://github.com/hughsie/%{name}/releases/download/%{version}/%{name}-%{version}.tar.xz

BuildRequires:  meson
BuildRequires:  gtk-doc
BuildRequires:  pkgconfig(glib-2.0) >= %{glib2_version}
BuildRequires:  libstemmer-devel
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(libzstd)
BuildRequires:  python3-setuptools

# needed for the self tests
BuildRequires:  shared-mime-info

Requires:       shared-mime-info

%description
XML is slow to parse and strings inside the document cannot be memory mapped as
they do not have a trailing NUL char. The libxmlb library takes XML source, and
converts it to a structured binary representation with a deduplicated string
table -- where the strings have the NULs included.

This allows an application to mmap the binary XML file, do an XPath query and
return some strings without actually parsing the entire document. This is all
done using (almost) zero allocations and no actual copying of the binary data.

%package -n %{libname}
Summary:        Library for querying compressed XML metadata
Group:          System/Libraries

%description -n %{libname}
XML is slow to parse and strings inside the document cannot be memory mapped as
they do not have a trailing NUL char. The libxmlb library takes XML source, and
converts it to a structured binary representation with a deduplicated string
table -- where the strings have the NULs included.

This allows an application to mmap the binary XML file, do an XPath query and
return some strings without actually parsing the entire document. This is all
done using (almost) zero allocations and no actual copying of the binary data.

%package -n %{girname}
Summary:        GObject Introspection interface description for %{name}
Group:          System/Libraries
Requires:       %{libname} = %{version}-%{release}

%description -n %{girname}
GObject Introspection interface description for %{name}.

%package -n %{devname}
Group:          Development/C
Summary:        Development package for %{name}
Requires:       %{libname} = %{version}-%{release}
Requires:       %{girname} = %{version}-%{release}
Provides:       libxmlb-devel = %{version}-%{release}

%description -n %{devname}
Files for development with %{name}.

%package tests
Summary:        Files for installed tests
Group:          System/Libraries

%description tests
Executable and data files for installed tests.

%prep
%autosetup -p1

%build
%meson \
    -Dgtkdoc=true \
    -Dtests=true

%meson_build

%check
%meson_test

%install
%meson_install

%files
%doc README.md
%license LICENSE
%{_bindir}/xb-tool
%{_mandir}/man1/xb-tool.1*

%files -n %{libname}
%doc README.md
%license LICENSE
%{_libdir}/libxmlb.so.%{major}{,.*}

%files -n %{girname}
%license LICENSE
%{_libdir}/girepository-1.0/Xmlb-%{gir_major}.typelib

%files -n %{devname}
%{_datadir}/gir-1.0/Xmlb-%{gir_major}.gir
%{_datadir}/gtk-doc/html/libxmlb
%{_includedir}/libxmlb-2/
%{_libdir}/libxmlb.so
%{_libdir}/pkgconfig/xmlb.pc

%files tests
%{_libexecdir}/installed-tests/libxmlb/
%dir %{_datadir}/installed-tests/libxmlb
%{_datadir}/installed-tests/libxmlb/libxmlb.test


%changelog
* Tue Mar 25 2025 daviddavid <daviddavid> 0.3.22-1.mga10
+ Revision: 2169750
- new version: 0.3.22

* Sun Dec 01 2024 daviddavid <daviddavid> 0.3.21-1.mga10
+ Revision: 2120316
- new version: 0.3.21

* Sun Nov 05 2023 daviddavid <daviddavid> 0.3.14-1.mga10
+ Revision: 2004284
- new version: 0.3.14

* Mon Feb 27 2023 luigiwalser <luigiwalser> 0.3.11-1.mga9
+ Revision: 1945626
- 0.3.11
- update source URL

* Tue Sep 27 2022 luigiwalser <luigiwalser> 0.3.10-1.mga9
+ Revision: 1892595
- 0.3.10

* Sat Mar 19 2022 umeabot <umeabot> 0.3.6-2.mga9
+ Revision: 1800085
- Mageia 9 Mass Rebuild

* Mon Dec 13 2021 tv <tv> 0.3.6-1.mga9
+ Revision: 1761885
- New upstream release 0.3.6

* Thu Dec 02 2021 tv <tv> 0.3.5-1.mga9
+ Revision: 1760586
- New upstream release 0.3.5

* Tue Nov 30 2021 tv <tv> 0.3.4-1.mga9
+ Revision: 1760079
- New upstream release 0.3.4

* Mon Oct 11 2021 tv <tv> 0.3.3-1.mga9
+ Revision: 1750587
- New upstream release

* Mon Jun 07 2021 tv <tv> 0.3.2-1.mga9
+ Revision: 1730069
- 0.3.2

* Fri May 07 2021 tv <tv> 0.3.1-1.mga9
+ Revision: 1722244
- 0.3.1

* Sat Mar 13 2021 tv <tv> 0.3.0-1.mga9
+ Revision: 1701917
- 3.0.0

* Mon Sep 07 2020 tv <tv> 0.2.1-1.mga8
+ Revision: 1623386
- 0.2.1

* Tue Aug 18 2020 tv <tv> 0.2.0-1.mga8
+ Revision: 1615383
- 0.2.0

* Sat Apr 04 2020 tv <tv> 0.1.15-1.mga8
+ Revision: 1564337
- 0.1.15

* Wed Feb 19 2020 umeabot <umeabot> 0.1.14-2.mga8
+ Revision: 1543156
- Mageia 8 Mass Rebuild

* Wed Jan 15 2020 luigiwalser <luigiwalser> 0.1.14-1.mga8
+ Revision: 1478117
- 0.1.14
- do not use libuuid (from fedora)

* Mon Oct 28 2019 tv <tv> 0.1.13-1.mga8
+ Revision: 1456246
- new release

* Thu Apr 18 2019 umeabot <umeabot> 0.1.8-2.mga7
+ Revision: 1392796
- Rebuild with meson 0.50.1

* Tue Apr 16 2019 daviddavid <daviddavid> 0.1.8-1.mga7
+ Revision: 1391182
- new version: 0.1.8

* Thu Jan 31 2019 daviddavid <daviddavid> 0.1.6-3.mga7
+ Revision: 1362103
- split out typelib library into his own sub-pkg
- fix dependecies

* Thu Jan 31 2019 tv <tv> 0.1.6-2.mga7
+ Revision: 1362047
- add devel provides
- new release (aka import working one from FC)
+ ovitters <ovitters>
- from OpenMandriva

